@@ -7,4 +7,4 @@ hdiutil attach -noverify -readonly -mountpoint _mount ql.dmg
 cp -R _mount/QuodLibet.app "$TMPDIR/_app"
 hdiutil detach -force _mount
 RUN="$TMPDIR/_app/Contents/MacOS/run"
-$RUN -m pip install flake8==4.0.1 pytest pytest-faulthandler flaky "coverage[toml]"
+$RUN -m pip install "ruff==0.7.3" "pytest==7.4.4" pytest-faulthandler flaky "coverage[toml]"
