@@ -19,9 +19,9 @@ git log \
     --pretty=format:"%s|%b" \
     --merges \
     --since="$from_date" \
-    --grep "pull request" \
-    | sed -nre "s/$GIT_REGEX"'/ * \3 :pr:`\1` (:user:`\2`)/p'
-echo -e "\n\nMaster:"
+    --grep "pull request" |
+    sed -nre "s/$GIT_REGEX"'/ * \3 :pr:`\1` (:user:`\2`)/p'
+echo -e "\n\nMain:"
 git log \
     --pretty=format:"%aN|%s" \
     --no-merges \
@@ -31,11 +31,12 @@ git log \
     --grep "Translated using Weblate" \
     --grep "Update quodlibet.pot" \
     --first-parent main \
-    --since="$from_date" \
-    | sed -nre 's/(.+)+\|(.*)/ * \2 (:user:`\1`)/p' \
-    | sed -r \
-          -e 's/`Nick B`|`Nick Boultbee`/`Nick Boultbee <declension>`/g' \
-          -e 's/`lazka`/`Christoph Reiter <lazka>`/g' \
-          -e 's/`Christoph Reiter`|`lazka`/`Christoph Reiter <lazka>`/g' \
-          -e 's/`Joschua Gandert`/`Joschua Gandert <CreamyCookie>`/g'
+    --since="$from_date" |
+    sed -nre 's/\(#([0-9]+)\)$/:pr:`\1`/p' |
+    sed -nre 's/(.+)+\|(.*)/ * \2 (:user:`\1`)/p' |
+    sed -r \
+        -e 's/`Nick B`|`Nick Boultbee`/`Nick Boultbee <declension>`/g' \
+        -e 's/`lazka`/`Christoph Reiter <lazka>`/g' \
+        -e 's/`Christoph Reiter`|`lazka`/`Christoph Reiter <lazka>`/g' \
+        -e 's/`Joschua Gandert`/`Joschua Gandert <CreamyCookie>`/g'
 echo
