@@ -6,7 +6,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-DIR="$( cd "$( dirname "$0" )" && pwd )"
+DIR="$(cd "$(dirname "$0")" && pwd)"
 # shellcheck source-path=SCRIPTDIR
 source "$DIR"/_base.sh
 
@@ -17,14 +17,10 @@ function main {
     GIT_TAG=${1:-"$CURRENT_BRANCH"}
     echo "Building: $GIT_TAG"
 
-    [[ -d "${BUILD_ROOT}" ]] && (echo "${BUILD_ROOT} already exists"; exit 1)
-
-    # started from the wrong env -> switch
-    # shellcheck disable=SC2019,SC2018
-    if [ "$(echo "$MSYSTEM" | tr 'A-Z' 'a-z')" != "$MINGW" ]; then
-        "/${MINGW}.exe" "$0" "$1"
-        exit $?
-    fi
+    [[ -d ${BUILD_ROOT} ]] && (
+        echo "${BUILD_ROOT} already exists"
+        exit 1
+    )
 
     install_pre_deps
     create_root
@@ -36,4 +32,4 @@ function main {
     build_portable_installer
 }
 
-main "$@";
+main "$@"
