@@ -23,39 +23,39 @@ def exec_module(path):
     module.__dict__.update(globals_)
     return module
 
+
 const = exec_module(os.path.join(dir_, "..", "quodlibet", "const.py"))
 
 needs_sphinx = "1.3"
 
 sys.path.append(os.path.join(dir_, "ext"))
 
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.extlinks', 'contributors']
+extensions = ["sphinx.ext.autodoc", "sphinx.ext.extlinks", "contributors"]
 
-source_suffix = '.rst'
-root_doc = 'index'
-project = 'Quod Libet'
-copyright = u""
-exclude_patterns = ['_build', '_build_all', 'README.rst', '**/README.rst']
+source_suffix = ".rst"
+root_doc = "index"
+project = "Quod Libet"
+copyright = ""
+exclude_patterns = ["_build", "_build_all", "README.rst", "**/README.rst"]
 html_theme = "sphinx_rtd_theme"
 html_title = project
+# https://www.sphinx-doc.org/en/master/usage/configuration.html#confval-suppress_warnings
+suppress_warnings = ["config.cache"]
 
 extlinks = {
-    'bug': ('https://github.com/quodlibet/quodlibet/issues/%s', '#%s'),
-    'pr': ('https://github.com/quodlibet/quodlibet/pull/%s', '#%s'),
-    'user': ('https://github.com/%s', '%s'),
+    "bug": ("https://github.com/quodlibet/quodlibet/issues/%s", "#%s"),
+    "pr": ("https://github.com/quodlibet/quodlibet/pull/%s", "#%s"),
+    "user": ("https://github.com/%s", "%s"),
 }
 
 linkcheck_anchors = True
 linkcheck_workers = 20
-linkcheck_ignore = [
-    r".*groups\.google\.com/.*",
-    r".*keyserver\.ubuntu\.com.*"
-]
+linkcheck_ignore = [r".*groups\.google\.com/.*", r".*keyserver\.ubuntu\.com.*"]
 
 html_context = {
-    'extra_css_files': [
-        '//quodlibet.github.io/fonts/font-mfizz.css',
-        '_static/extra.css',
+    "extra_css_files": [
+        "//quodlibet.github.io/fonts/font-mfizz.css",
+        "_static/extra.css",
     ],
 }
 
@@ -72,4 +72,4 @@ html_show_copyright = False
 
 
 def setup(app):
-    app.add_config_value('const', const, True)
+    app.add_config_value("const", const, True)
