@@ -31,7 +31,7 @@ from .util import get_dist_class
 distutils_clean = get_dist_class("clean")
 
 
-class clean(distutils_clean):
+class Clean(distutils_clean):
     """clean up output of 'build' commands
 
     GDistribution commands generate files that the normal distutils
@@ -67,18 +67,19 @@ class clean(distutils_clean):
 
         # Python byproducts
         def should_remove(filename):
-            if (filename.lower()[-4:] in [".pyc", ".pyo"] or
-                    filename.endswith("~") or
-                    (filename.startswith("#") and filename.endswith("#"))):
+            if (
+                filename.lower()[-4:] in [".pyc", ".pyo"]
+                or filename.endswith("~")
+                or (filename.startswith("#") and filename.endswith("#"))
+            ):
                 return True
-            else:
-                return False
+            return False
 
-        for pathname, dirs, files in os.walk("."):
+        for pathname, _dirs, files in os.walk("."):
             for filename in filter(should_remove, files):
                 try:
                     os.unlink(os.path.join(pathname, filename))
-                except EnvironmentError as err:
+                except OSError as err:
                     print(str(err))
 
         # setup.py byproducts
@@ -94,7 +95,8 @@ class clean(distutils_clean):
 
         try:
             os.remove("MANIFEST")
-        except EnvironmentError:
+        except OSError:
             pass
 
-__all__ = ["clean"]
+
+__all__ = ["Clean"]
