@@ -17,8 +17,10 @@ class FollowOrder(ShufflePlugin, OrderInOrder, OrderRemembered):
     PLUGIN_ID = "follow"
     PLUGIN_NAME = _("Follow Cursor")
     PLUGIN_ICON = Icons.GO_JUMP
-    PLUGIN_DESC = _("Adds a play order mode that follows your selection, "
-                    "or the next song in the list once exhausted.")
+    PLUGIN_DESC = _(
+        "Adds a play order mode that follows your selection, "
+        "or the next song in the list once exhausted."
+    )
     display_name = _("Follow cursor")
     accelerated_name = _("_Follow cursor")
 
