@@ -20,7 +20,6 @@ from quodlibet.util import print_w
 from quodlibet.util.urllib import urlopen, Request
 from .util import get_api_key, GateKeeper
 
-
 APP_KEY = "C6IduH7D"
 gatekeeper = GateKeeper(requests_per_sec=3)
 
@@ -55,11 +54,13 @@ class AcoustidSubmissionThread(threading.Thread):
 
         self.__done += len(urldata)
 
-        basedata = urlencode({
-            "format": "xml",
-            "client": APP_KEY,
-            "user": get_api_key(),
-        })
+        basedata = urlencode(
+            {
+                "format": "xml",
+                "client": APP_KEY,
+                "user": get_api_key(),
+            }
+        )
 
         urldata = "&".join([basedata] + list(map(urlencode, urldata)))
         obj = BytesIO()
@@ -68,33 +69,35 @@ class AcoustidSubmissionThread(threading.Thread):
 
         headers = {
             "Content-Encoding": "gzip",
-            "Content-type": "application/x-www-form-urlencoded"
+            "Content-type": "application/x-www-form-urlencoded",
         }
         req = Request(self.URL, urldata, headers)
 
         error = None
         try:
             response = urlopen(req, timeout=self.TIMEOUT)
-        except EnvironmentError as e:
+        except OSError as e:
             error = "urllib error: " + str(e)
         else:
             xml = response.read()
             try:
                 dom = parseString(xml)
-            except:
+            except Exception:
                 error = "xml error"
             else:
                 status = dom.getElementsByTagName("status")
-                if not status or not status[0].childNodes or not \
-                    status[0].childNodes[0].nodeValue == "ok":
+                if (
+                    not status
+                    or not status[0].childNodes
+                    or not status[0].childNodes[0].nodeValue == "ok"
+                ):
                     error = "response status error"
 
         if error:
             print_w("[fingerprint] Submission failed: " + error)
 
         # emit progress
-        self.__idle(self.__progress_cb,
-                float(self.__done) / len(self.__results))
+        self.__idle(self.__progress_cb, float(self.__done) / len(self.__results))
 
     def run(self):
         urldata = []
@@ -148,7 +151,6 @@ class AcoustidSubmissionThread(threading.Thread):
 
 
 class LookupResult:
-
     def __init__(self, fresult, releases, error):
         self.fresult = fresult
         self.releases = releases
@@ -160,8 +162,10 @@ class LookupResult:
 
 
 Release = collections.namedtuple(
-    "Release", ["id", "score", "sources", "all_sources",
-                "medium_count", "tags"])
+    "Release", ["id", "score", "sources", "all_sources", "medium_count", "tags"]
+)
+
+VARIOUS_ARTISTS_ARTISTID = "89ad4ac3-39f7-470e-963a-56509c546377"
 
 
 def parse_acoustid_response(json_data):
@@ -174,8 +178,6 @@ def parse_acoustid_response(json_data):
     Needs meta=releases+recordings+tracks responses.
     """
 
-    VARIOUS_ARTISTS_ARTISTID = "89ad4ac3-39f7-470e-963a-56509c546377"
-
     releases = []
     for res in json_data.get("results", []):
         score = res["score"]
@@ -195,7 +197,7 @@ def parse_acoustid_response(json_data):
                 album = release.get("title", "")
                 album_id = release["id"]
                 parts = [date.get(k) for k in ["year", "month", "day"]]
-                date = "-".join([u"%02d" % p for p in parts if p is not None])
+                date = "-".join(["%02d" % p for p in parts if p is not None])
 
                 albumartists = []
                 albumartist_ids = []
@@ -217,14 +219,14 @@ def parse_acoustid_response(json_data):
                 title = track_info.get("title", "")
 
                 if disc and discs > 1:
-                    discnumber = u"%d/%d" % (disc, discs)
+                    discnumber = f"{disc:d}/{discs:d}"
                 else:
-                    discnumber = u""
+                    discnumber = ""
 
                 if track and tracks > 1:
-                    tracknumber = u"%d/%d" % (track, tracks)
+                    tracknumber = f"{track:d}/{tracks:d}"
                 else:
-                    tracknumber = u""
+                    tracknumber = ""
 
                 tags = {
                     "title": title,
@@ -284,18 +286,26 @@ class AcoustidLookupThread(threading.Thread):
 
     def __process(self, results):
         req_data = []
-        req_data.append(urlencode({
-            "format": "json",
-            "client": APP_KEY,
-            "batch": "1",
-        }))
+        req_data.append(
+            urlencode(
+                {
+                    "format": "json",
+                    "client": APP_KEY,
+                    "batch": "1",
+                }
+            )
+        )
 
         for i, result in enumerate(results):
             postfix = ".%d" % i
-            req_data.append(urlencode({
-                "duration" + postfix: str(int(round(result.length))),
-                "fingerprint" + postfix: result.chromaprint,
-            }))
+            req_data.append(
+                urlencode(
+                    {
+                        "duration" + postfix: str(int(round(result.length))),
+                        "fingerprint" + postfix: result.chromaprint,
+                    }
+                )
+            )
 
         req_data.append("meta=releases+recordings+tracks+sources")
 
@@ -306,7 +316,7 @@ class AcoustidLookupThread(threading.Thread):
 
         headers = {
             "Content-Encoding": "gzip",
-            "Content-type": "application/x-www-form-urlencoded"
+            "Content-type": "application/x-www-form-urlencoded",
         }
         req = Request(self.URL, urldata, headers)
 
@@ -314,7 +324,7 @@ class AcoustidLookupThread(threading.Thread):
         error = ""
         try:
             response = urlopen(req, timeout=self.TIMEOUT)
-        except EnvironmentError as e:
+        except OSError as e:
             error = "urllib error: " + str(e)
         else:
             try:
