@@ -21,7 +21,6 @@ from tests import skipIf, run_gtk_loop
 
 @skipIf(os.name == "nt", "mpd server not supported under Windows")
 class TMPDServer(PluginTestCase):
-
     def setUp(self):
         self.mod = self.modules["mpd_server"]
 
@@ -32,17 +31,17 @@ class TMPDServer(PluginTestCase):
         self.assertEqual(parse(b"foo\tbar"), ("foo", ["bar"]))
         self.assertEqual(parse(b"foo\t bar"), ("foo", ["bar"]))
         self.assertEqual(parse(b"foo\t bar quux"), ("foo", ["bar", "quux"]))
-        self.assertEqual(
-            parse(b"foo\t bar \"q 2\" x"), ("foo", ["bar", "q 2", "x"]))
+        self.assertEqual(parse(b'foo\t bar "q 2" x'), ("foo", ["bar", "q 2", "x"]))
         self.assertEqual(parse(b"foo 'bar  quux'"), ("foo", ["'bar", "quux'"]))
         self.assertEqual(
-            parse(b"foo \xc3\xb6\xc3\xa4\xc3\xbc"), ("foo", [u"\xf6\xe4\xfc"]))
+            parse(b"foo \xc3\xb6\xc3\xa4\xc3\xbc"), ("foo", ["\xf6\xe4\xfc"])
+        )
 
     def test_format_tags(self):
         format_tags = self.mod.main.format_tags
 
         def getline(key, value):
-            song = AudioFile({"~filename": fsnative(u"/dev/null")})
+            song = AudioFile({"~filename": fsnative("/dev/null")})
             song.sanitize()
             song[key] = value
             lines = format_tags(song).splitlines()
@@ -54,6 +53,7 @@ class TMPDServer(PluginTestCase):
             for l in lines:
                 if not l.startswith("Title"):
                     return l
+            return None
 
         self.assertEqual(getline("artist", "foo"), "Artist: foo")
         self.assertEqual(getline("genre", "foo\nbar"), "Genre: foo, bar")
@@ -65,7 +65,6 @@ class TMPDServer(PluginTestCase):
 
 @skipIf(os.name == "nt", "mpd server not supported under Windows")
 class TMPDCommands(PluginTestCase):
-
     def setUp(self):
         self.mod = self.modules["mpd_server"]
         config.init()
@@ -99,16 +98,21 @@ class TMPDCommands(PluginTestCase):
             Gtk.main_iteration_do(True)
         if data.strip() != b"idle":
             return self.s.recv(99999)
+        return None
 
     def tearDown(self):
         destroy_fake_app()
         config.quit()
 
     def test_currentsong_length(self):
-        app.player.go_to(AudioFile({
-            "~filename": fsnative(),
-            "~#length": 12.25,
-        }))
+        app.player.go_to(
+            AudioFile(
+                {
+                    "~filename": fsnative(),
+                    "~#length": 12.25,
+                }
+            )
+        )
 
         response = self._cmd(b"currentsong\n")
         assert b"Time: 12\n" in response
@@ -123,6 +127,11 @@ class TMPDCommands(PluginTestCase):
         for cmd in cmds:
             self._cmd(cmd.encode("ascii") + b"\n")
 
+    def test_seekcur(self):
+        # Ensure we can handle both integer and float arguments.
+        for cmd in ["seekcur 1", "seekcur 1.5"]:
+            self._cmd(cmd.encode("ascii") + b"\n")
+
     def test_idle_close(self):
         for cmd in ["idle", "noidle", "close"]:
             self._cmd(cmd.encode("ascii") + b"\n")
