@@ -8,19 +8,26 @@ from tests.helper import __
 
 import os
 import sys
-sys.modules['dircache'] = os # cheat the dircache effects
+
+sys.modules["dircache"] = os  # cheat the dircache effects
 
 from senf import fsnative
 
-from quodlibet.qltk.filesel import DirectoryTree, FileSelector, get_drives, \
-    MainDirectoryTree, MainFileSelector, get_gtk_bookmarks, parse_gtk_bookmarks
+from quodlibet.qltk.filesel import (
+    DirectoryTree,
+    FileSelector,
+    get_drives,
+    MainDirectoryTree,
+    MainFileSelector,
+    get_gtk_bookmarks,
+    parse_gtk_bookmarks,
+)
 from quodlibet.util.path import get_home_dir
 import quodlibet.config
 from quodlibet.util import is_windows
 
 
 class Tget_gtk_bookmarks(TestCase):
-
     def test_main(self):
         paths = get_gtk_bookmarks()
         assert all(isinstance(p, fsnative) for p in paths)
@@ -29,16 +36,17 @@ class Tget_gtk_bookmarks(TestCase):
         if is_windows():
             return
 
-        data = (b'file:///foo/bar\nfile:///home/user\n'
-                b'file:///home/user/Downloads Downloads\n')
+        data = (
+            b"file:///foo/bar\nfile:///home/user\n"
+            b"file:///home/user/Downloads Downloads\n"
+        )
         paths = parse_gtk_bookmarks(data)
         assert all(isinstance(p, fsnative) for p in paths)
 
 
 class TDirectoryTree(TestCase):
-
     if os.name == "nt":
-        ROOTS = [get_home_dir(), u"C:\\"]
+        ROOTS = [get_home_dir(), "C:\\"]
     else:
         ROOTS = [get_home_dir(), "/"]
 
@@ -50,7 +58,7 @@ class TDirectoryTree(TestCase):
 
     def test_initial(self):
         if os.name == "nt":
-            paths = [u"C:\\", get_home_dir()]
+            paths = ["C:\\", get_home_dir()]
         else:
             paths = ["/", get_home_dir()]
 
@@ -59,7 +67,7 @@ class TDirectoryTree(TestCase):
             model, rows = dirlist.get_selection().get_selected_rows()
             selected = [model[row][0] for row in rows]
             dirlist.destroy()
-            self.failUnlessEqual([os.path.normpath(path)], selected)
+            self.assertEqual([os.path.normpath(path)], selected)
 
     def test_bad_initial(self):
         invalid = os.path.join("bin", "file", "does", "not", "exist")
@@ -70,37 +78,37 @@ class TDirectoryTree(TestCase):
             dirlist.destroy()
             # select the last valid parent directory
             self.assertEqual(len(selected), 1)
-            self.assertTrue(selected[0].startswith(path))
+            assert selected[0].startswith(path)
 
     def test_bad_go_to(self):
-        newpath = fsnative(u"/woooooo/bar/fun/broken")
-        dirlist = DirectoryTree(fsnative(u"/"), folders=self.ROOTS)
+        newpath = fsnative("/woooooo/bar/fun/broken")
+        dirlist = DirectoryTree(fsnative("/"), folders=self.ROOTS)
         dirlist.go_to(newpath)
         dirlist.destroy()
 
     def test_main(self):
         folders = ["/"]
         if os.name == "nt":
-            folders = [u"C:\\"]
+            folders = ["C:\\"]
         main = MainDirectoryTree(folders=folders)
-        self.assertTrue(len(main.get_model()))
+        assert len(main.get_model())
 
         main = MainDirectoryTree()
-        self.assertTrue(len(main.get_model()))
+        assert len(main.get_model())
 
     def test_get_drives(self):
         for path in get_drives():
-            self.assertTrue(isinstance(path, fsnative))
+            assert isinstance(path, fsnative)
 
     def test_popup(self):
         dt = DirectoryTree(None, folders=self.ROOTS)
         menu = dt._create_menu()
         dt._popup_menu(menu)
         children = menu.get_children()
-        self.failUnlessEqual(len(children), 4)
+        self.assertEqual(len(children), 4)
         delete = children[1]
-        self.failUnlessEqual(delete.get_label(), __("_Delete"))
-        self.failUnless(delete.get_sensitive())
+        self.assertEqual(delete.get_label(), __("_Delete"))
+        assert delete.get_sensitive()
 
     def test_multiple_selections(self):
         dt = DirectoryTree(None, folders=self.ROOTS)
@@ -108,22 +116,19 @@ class TDirectoryTree(TestCase):
         dt._popup_menu(menu)
         children = menu.get_children()
         select_sub = children[3]
-        self.failUnless("sub-folders" in select_sub.get_label().lower())
-        self.failUnless(select_sub.get_sensitive())
+        assert "sub-folders" in select_sub.get_label().lower()
+        assert select_sub.get_sensitive()
         sel = dt.get_selection()
         model = dt.get_model()
-        for it, pth in model.iterrows(None):
+        for it, _pth in model.iterrows(None):
             sel.select_iter(it)
-        self.failUnless(select_sub.get_sensitive(),
-                        msg="Select All should work for multiple")
-        self.failIf(children[0].get_sensitive(),
-                    msg="New Folder should be disabled for multiple")
-        self.failUnless(children[3].get_sensitive(),
-                        msg="Refresh should be enabled for multiple")
+        assert select_sub.get_sensitive(), "Select All should work for multiple"
+        msg = "New Folder should be disabled for multiple"
+        assert not children[0].get_sensitive(), msg
+        assert children[3].get_sensitive(), "Refresh should be enabled for multiple"
 
 
 class TFileSelector(TestCase):
-
     def setUp(self):
         quodlibet.config.init()
         self.ROOTS = [mkdtemp(), mkdtemp()]
@@ -137,9 +142,9 @@ class TFileSelector(TestCase):
             open(path, "wb").close()
 
         self.fs = FileSelector(
-            initial=self.INITIAL, filter=(lambda s: s in self.PATHS),
-            folders=self.ROOTS)
-        self.fs.connect('changed', self._changed)
+            initial=self.INITIAL, filter=(lambda s: s in self.PATHS), folders=self.ROOTS
+        )
+        self.fs.connect("changed", self._changed)
         self.files = None
         self.fs.rescan()
 
