@@ -32,9 +32,9 @@ class DummyPlugins:
 
 class TSongProperties(TestCase):
     af1 = AudioFile({"title": "woo"})
-    af1.sanitize(fsnative(u"invalid"))
+    af1.sanitize(fsnative("invalid"))
     af2 = AudioFile({"title": "bar", "album": "quux"})
-    af2.sanitize(fsnative(u"alsoinvalid"))
+    af2.sanitize(fsnative("alsoinvalid"))
 
     def setUp(self):
         SongProperties.plugins = DummyPlugins()
@@ -50,13 +50,13 @@ class TSongProperties(TestCase):
     def test_changed(self):
         self.test_twosong()
         self.window.hide()
-        self.library.emit('changed', [self.af2])
+        self.library.emit("changed", [self.af2])
         run_gtk_loop()
 
     def test_removed(self):
         self.test_twosong()
         self.window.hide()
-        self.library.emit('removed', [self.af2])
+        self.library.emit("removed", [self.af2])
         run_gtk_loop()
 
     def tearDown(self):
@@ -65,7 +65,7 @@ class TSongProperties(TestCase):
         except AttributeError:
             pass
         else:
-            del(self.window)
+            del self.window
         self.library.destroy()
-        del(SongProperties.plugins)
+        del SongProperties.plugins
         config.quit()
