@@ -11,12 +11,11 @@ from quodlibet.util.tags import sortkey, readable
 
 
 class TTags(TestCase):
-
     def test_basic(self):
         t = ["album", "title", "artist", "part", "musicbrainz_trackid"]
         t.sort(key=sortkey)
         expected = ["title", "artist", "album", "part", "musicbrainz_trackid"]
-        self.failUnlessEqual(t, expected)
+        self.assertEqual(t, expected)
 
     def test_readable(self):
         self.assertEqual(readable("artistsort"), "artist (sort)")
